.. Twitter-Bookmark-Downloader documentation master file, created by
   sphinx-quickstart on Wed Jul 13 17:00:40 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Twitter-Bookmark-Downloader's documentation!
=======================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   TwitterArchive


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
